@@ -39,10 +39,9 @@ typedef struct _sem {
 #ifndef ___M_THREAD_2_END_H___
 #define ___M_THREAD_2_END_H___
 
-/*
-#define SCHED_POLICY	SCHED_RR
-*/
-#define SCHED_POLICY	SCHED_OTHER
+
+#define SCHED_SUPER_POLICY	SCHED_RR
+#define SCHED_POLICY		SCHED_OTHER
 
 typedef struct sw_hash {
 	struct sw_hash *	next;
