@@ -135,8 +135,10 @@ int sig;
 		case SIGTERM:
 			continue;
 		}
+/*
 		if ( sig == 9 || sig == 10 )
 			continue;
+*/
 		sa.sa_handler = sig_empty_handler;
 		sigemptyset(&sa.sa_mask);
 		sa.sa_flags = 0;
@@ -353,9 +355,13 @@ int policy;
 
 	ret = pthread_attr_init(&tattr);
 
-	policy = SCHED_POLICY;
+	if ( pri < 0 ) {
+		policy = SCHED_SUPER_POLICY;
+		pri = 0;
+	}
+	else	policy = SCHED_POLICY;
 	ret = pthread_attr_setschedpolicy(&tattr,policy);
-	if ( SCHED_POLICY != SCHED_OTHER ) {
+	if ( policy != SCHED_OTHER ) {
 		pthread_attr_getschedparam(&tattr,&param);
 		if ( pri >= PRI_MAX )
 			pri = PRI_MAX-1;
