@@ -303,17 +303,13 @@ cnt ++;
 
 		g = get_surp_rect(&bw->surp,r);
 /*
-ss_printf("CC-- %i %i ++ \n",m->cindex_time,m->mod_time);
-ss_printf("(%f %f %f %f) (%f %f %f %f) ++ \n",
-m->cindex_mr.tl.x,
-m->cindex_mr.tl.y,
-m->cindex_mr.br.x,
-m->cindex_mr.br.y,
-g.tl.x,
-g.tl.y,
-g.br.x,
-g.br.y);
+if ( l_strcmp(r->h.entry.resource,l_string(std_cm,"05.crd")) == 0 )
+ss_printf("***************************\n");
+ss_printf("CC / %ls\n",get_url_str2(&r->h.entry));
+ss_printf("CC-- %i %i ++ %i\n",m->cindex_time,m->mod_time,
+m->cindex_time - m->mod_time);
 */
+/*
 		if ( m->cindex_time >= m->mod_time &&
 				m->cindex_mr.tl.x <= m->cindex_mr.br.x ) {
 			if ( cross_rect_rect(&m->cindex_mr,&g) == 0 ) {
@@ -323,6 +319,16 @@ g.br.y);
 				continue;
 			}
 		}
+*/
+		if ( m->cindex_mr.tl.x <= m->cindex_mr.br.x ) {
+			if ( cross_rect_rect(&m->cindex_mr,&g) == 0 ) {
+				lock_task(res_lock);
+				m->flags &= ~MF_BROWSE;
+				unlock_task(res_lock,"write_lock");
+				continue;
+			}
+		}
+
 		if ( m->src == 0 ) {
 			ret = new_lrw(ret);
 			copy_url(&ret->url,&m->src_url);
