@@ -1060,7 +1060,7 @@ int ret;
 set_t_msg(23);
 
 
-	ret = wf_set_current(now);
+	ret = _wf_set_current(now,0);
 	unlock_task(env.wf_lock,"wf_set_current_now");
 	return ret;
 }
