@@ -82,7 +82,8 @@ int interval;
 		er_panic("mp_counter(2)");
 	}
 	cnt = 0;
-	for ( ; get_type(file_list) ; file_list = cdr(file_list) ) {
+	for ( ; get_type(file_list) == XLT_PAIR ; 
+			file_list = cdr(file_list) ) {
 		t = car(file_list);
 		if ( get_type(t) != XLT_STRING ) {
 			fprintf(stderr,"type missmatch");
@@ -157,28 +158,6 @@ XL_SEXP * r;
 	return ret;
 }
 
-unsigned int
-get_file_modify(L_CHAR * filename,char * prefix)
-{
-URL u;
-L_CHAR * f;
-int ret;
-U_STAT buf;
-	get_url2(&u,filename,36);
-	f = get_access_path(&u,prefix);
-	if ( f == 0 )
-		return 0;
-	if ( u_stat(n_string(std_cm,f),&buf) < 0 ) {
-		ret = 0;
-		goto end;
-	}
-	ret = buf.us_mtime;
-end:
-	d_f_ree(f);
-	return ret;
-}
-
-
 int
 check_mapping(
 	L_CHAR * filename,
@@ -831,7 +810,7 @@ int flag;
 XL_SEXP * sym;
 	ret = 0;
 	flag = 0;
-	for ( ; get_type(s) ; s = cdr(s) ) {
+	for ( ; get_type(s) == XLT_PAIR ; s = cdr(s) ) {
 		t = car(s);
 		tm = xl_GetElement(gblisp_top_env0,
 			List(n_get_symbol("GetElement"),
@@ -921,7 +900,8 @@ static int trace_force = 2;
 		er_panic("trace_mapping(2)");
 	}
 	ses = open_session(SEST_OPTIMIZE);
-	for ( ; get_type(file_list) ; file_list = cdr(file_list) ) {
+	for ( ; get_type(file_list) == XLT_PAIR ; 
+			file_list = cdr(file_list) ) {
 		t = car(file_list);
 		if ( get_type(t) != XLT_STRING ) {
 			fprintf(stderr,"type missmatch");
@@ -930,6 +910,7 @@ static int trace_force = 2;
 			er_panic("trace_mapping(3)");
 		}
 		gc_push(0,0,"trace mapping");
+ss_printf("MAP %ls\n",t->string.data);
 		interval = ping_mapping(ses,t->string.data,trace_force);
 		gc_pop(0,0);
 		if ( interval >= 0 )
@@ -969,7 +950,8 @@ XL_SEXP * t;
 		s_printf(s_stderr,"\n");
 		er_panic("trace_crd_mapping(2)");
 	}
-	for ( ; get_type(file_list) ; file_list = cdr(file_list) ) {
+	for ( ; get_type(file_list) == XLT_PAIR ;
+			file_list = cdr(file_list) ) {
 		t = car(file_list);
 		if ( get_type(t) != XLT_STRING ) {
 			fprintf(stderr,"type missmatch");
