@@ -271,12 +271,12 @@ printf("loop\n");
 
 		task_timer[cpu] = get_xltime();
 		task_target[cpu] = t1;
-/*
+
 if ( t1->filename )
-printf(">>> %s %i %i\n",n_string(std_cm,t1->filename),t1->type,get_tid());
+log_printf(LOG_DEBUG,">>> %s %i %i\n",n_string(std_cm,t1->filename),t1->type,get_tid());
 else
-printf(">>> %i %i\n",t1->type,get_tid());
-*/
+log_printf(LOG_DEBUG,">>> %i %i\n",t1->type,get_tid());
+
 		gc_push(0,0,"acrp_task");
 		switch ( t1->type ) {
 		case TQT_CRD:
