@@ -79,9 +79,21 @@ typedef struct acc_pn_header {
 #define PNT_RT_CACHE_LIST	((PNT_RT_CACHE_GROUP<<8)|3)
 
 #define PNT_RS_CACHE_GROUP	5
-#define PNT_RS_CACHE_HEADER	((PNT_RT_CACHE_GROUP<<8)|1)
-#define RNT_RS_RES_HEADER	((PNT_RT_CACHE_GROUP<<8)|2)
-#define RNT_RS_STRING		((PNT_RT_CACHE_GROUP<<8)|3)
+#define PNT_RS_CACHE_NULL	((PNT_RS_CACHE_GROUP<<8)|0)
+#define PNT_RS_CACHE_HEADER	((PNT_RS_CACHE_GROUP<<8)|1)
+#define PNT_RS_CACHE_DATA	((PNT_RS_CACHE_GROUP<<8)|2)
+#define PNT_RS_RES_STATUS	((PNT_RS_CACHE_GROUP<<8)|3)
+#define PNT_RS_COORDINATE	((PNT_RS_CACHE_GROUP<<8)|4)
+#define PNT_RS_PIXEL_MAP_R64	((PNT_RS_CACHE_GROUP<<8)|5)
+#define PNT_RS_DRAW_GB		((PNT_RS_CACHE_GROUP<<8)|6)
+#define PNT_RS_RES_MAP		((PNT_RS_CACHE_GROUP<<8)|7)
+#define PNT_RS_BIB_LIST		((PNT_RS_CACHE_GROUP<<8)|8)
+#define PNT_RS_NOTE		((PNT_RS_CACHE_GROUP<<8)|9)
+#define PNT_RS_CLIP		((PNT_RS_CACHE_GROUP<<8)|10)
+#define PNT_RS_MAP		((PNT_RS_CACHE_GROUP<<8)|11)
+#define PNT_RS_INFO_SCHEME	((PNT_RS_CACHE_GROUP<<8)|12)
+#define PNT_RS_TRIANGLE		((PNT_RS_CACHE_GROUP<<8)|13)
+#define PNT_RS_MAP_POINT_LIST	((PNT_RS_CACHE_GROUP<<8)|14)
 
 
 /*******************************/
@@ -461,6 +473,9 @@ typedef struct pn_rt_cache_list {
  */
 /*******************************/
 
+#define FAT_RSC_URL	0x301
+#define FAT_RSC_TIMER	0x302
+
 
 typedef struct pn_rs_cache_header {
 	PN_HEADER		h;
@@ -470,7 +485,343 @@ typedef struct pn_rs_cache_header {
 	unsigned int		timer_tree;
 	int			count;
 	int			flags;
-} RN_RS_CACHE_HEADER;
+	int			file_id;
+} PN_RS_CACHE_HEADER;
+
+
+typedef struct pn_rs_cache_data {
+	PN_HEADER	h;
+	unsigned int	expire;
+	int		file_id;
+} PN_RS_CACHE_DATA;
+
+typedef struct pn_rs_res_status {
+	PN_HEADER	pn_h;
+	char		version[8];
+#define PNRS_T_RESOURCE	1
+	int		type;
+} PN_RS_RES_STATUS;
+
+typedef struct pn_rs_res_header {
+
+	PN_HEADER	pn_h;
+
+/* copy of resource.h res_header */
+/* cut
+	union resource * entry_next;
+	union resource * target_next;
+	union resource * no_next;
+*/
+	int		type;
+	/* type equal to RT_.... parameter */
+/* string after this structure
+	URL		entry;
+	URL		target;
+*/
+/* cut
+	int		no;
+*/
+	int		flags;
+	unsigned int	modify;
+	GB_RECT		minrect;
+/* string after this structure
+	XL_SEXP *	meta;
+*/
+/* cut
+	int		initial_status;
+	XL_SEXP *	initial_error;
+	int		incremental_status;
+	XL_SEXP *	incremental_error;
+	int		error_time;
+	int		error_expire;
+*/
+/* BIB records
+	BIB_LIST *	bib;
+*/
+/* NOTE recors
+	NOTE *		notes;
+*/
+	REAL1		visible_resolution;
+/* string after this structure SYSTEM and UNIT
+	COORDINATE_UNIT cu;
+*/
+} PN_RS_RES_HEADER;
+
+
+
+typedef struct pn_rs_bib_list {
+
+	PN_HEADER		pn_h;
+
+/* copy from resource.h */
+/* cut
+	struct bib_list *	next;
+*/
+	int			inherit;
+/* string after this structure
+	L_CHAR *		namespace;
+	L_CHAR *		qualifier;
+	L_CHAR *		type;
+	L_CHAR *		data;
+*/
+} PN_RS_BIB_LIST;
+
+typedef struct pn_rs_note {
+
+	PN_HEADER		pn_h;
+
+/* copy from resource.h */
+/* cut
+	struct note *		next;
+*/
+	int			type;
+/* string after this structure
+	L_CHAR *		img;
+*/
+	int			fill_color;
+	int			line_color;
+/* string after this structure
+	L_CHAR *		data;
+	L_CHAR *		url;
+*/
+} PN_RS_NOTE;
+
+
+
+typedef struct pn_rs_pixel_map_r64 {
+	PN_RS_RES_HEADER	h;
+	REAL1		dpm;
+	unsigned char	type;
+	/*
+		'P'	R64 RGB
+		'G'	R64 Gray Scale
+		'B'	R64 Bitmap
+		'0'	CR 64 sqare RGB
+		'1'	CR 128 sqare RGB
+		'2'	CR 256 sqare RGB
+	*/
+	int		width[32];
+	int		height[32];
+	int		max_level;
+/* cut
+	TREE_CACHE	tc;
+	int		loop_no;
+*/
+} PN_RS_PIXEL_MAP_R64;
+
+
+typedef struct pn_rs_coordinate {
+	PN_RS_RES_HEADER	h;
+	int		flags;
+	int		geometory_type;
+/* cut
+	double *	geometory_param;
+*/
+	REAL1		limit_resolution;
+/* MAP records
+	RING_TYPE	map_children;
+	RING_TYPE	map_parents;
+*/
+/* cut
+	OVERLAY *	ov;
+*/
+	REAL1		weight;
+/* string after this structure
+	L_CHAR *	mode;
+	XL_SEXP *	initial_cmd;
+	XL_SEXP *	button_action;
+*/
+/* CID string after this structure
+	int *		cid;
+*/
+/* string after this structure
+	L_CHAR *	body;
+	L_CHAR *	body_pri;
+
+	L_CHAR *	relation_master;
+	L_CHAR *	relation_slave;
+*/
+/* CLIP record
+	CLIP *			clip;
+*/
+} PN_RS_COORDINATE;
+
+
+typedef struct pn_rs_clip {
+
+	PN_HEADER		pn_h;
+/*
+	struct clip *		next;
+*/
+	short			type;
+	short			shape;
+	union {
+		GB_RECT			rect;
+	}			d;
+} PN_RS_CLIP;
+
+
+typedef struct pn_rs_map {
+
+	PN_HEADER		pn_h;
+
+/* cut
+	RING_TYPE		h;
+*/
+	short			depth;
+	short			flags;
+/* cut
+	union resource *	src;
+	union resource *	dest;
+	union resource *	map_file;
+*/
+/* string after this structure
+	URL			src_url;
+	URL			dest_url;
+	URL			map_url;
+*/
+	unsigned int		mod_time_org;
+	unsigned int		mod_time;
+	unsigned int		cindex_time;
+	GB_RECT			cindex_mr;
+/* CLIP record
+	CLIP *			clip;
+*/
+} PN_RS_MAP;
+
+
+
+typedef struct pn_rs_draw_gb {
+	PN_RS_RES_HEADER	h;
+	int		type;
+	short		level;
+/* dummy */
+	short		pdb_lock;
+/**/
+	int		flags;
+/* cut
+	int		pdb_lock_task;
+	int		pdb_lock_msg;
+	int		pdb_lock_gc_flag;
+*/
+	REAL1		resolution;
+/* cut
+	AVT_NODE *	obj_code_tree;
+	RECT_TREE	obj_rect_tree;
+*/
+	GB_POINT	matrix_ofs;
+/* cut
+	DRAW_MATRIX *	dm;
+*/
+
+	GB_POINT	pitch_list[32];
+	int		loop_no;
+/* cut
+	INFO_REQ_QUEUE * ir_queue;
+*/
+/* INFO_SCHEME record
+	INFO_SCHEME *	ischeme;
+*/
+	REAL1		onmap_indicate_size;
+	short		hit_level;
+	short		hit_outofcircle;
+
+} PN_RS_DRAW_GB;
+
+typedef struct pn_rs_info_scheme {
+
+	PN_HEADER		pn_h;
+
+/* cut
+	struct info_scheme *	next;
+*/
+/* string after this structure
+	L_CHAR *		scheme;
+*/
+	short			card_type;
+	short			onmap_type;
+	/* these are same as STYLE_FILE.type */
+/* string after this structure
+	L_CHAR *		card_style;
+	L_CHAR *		onmap_style;
+*/
+} PN_RS_INFO_SCHEME;
+
+typedef struct pn_rs_triangle_set {
+	int			sts;
+	int			cnt;
+	AFFEN2D			a;
+	GB_RECT			minrect;
+	REAL1			resolution_rate;
+/* TRIANGLE records : 
+		the list of pair of PN_RS_TRIANGLE
+		1st is param_forward
+		2nd is param_reverse
+	TRIANGLE *		tri_list;
+*/
+} PN_RS_TRIANGLE_SET;
+
+typedef struct pn_rs_map_parameter {
+	int	type;
+	REAL1	resolution_rate;
+	union {
+		GB_POINT	ptr;
+		AFFEN2D		affen;
+		PN_RS_TRIANGLE_SET	tri;
+	}	opt;
+} PN_RS_MAP_PARAMETER;
+
+
+typedef struct pn_rs_res_map {
+	PN_RS_RES_HEADER	h;
+/* string after this structure
+	URL		src;
+	URL		dest;
+	COORDINATE_UNIT	cu_src;
+	COORDINATE_UNIT	cu_dest;
+*/
+/* MAP POINT LIST RECORDS 
+	RING_TYPE	point_list;
+*/
+	PN_RS_MAP_PARAMETER		param_forward;
+	PN_RS_MAP_PARAMETER		param_reverse;
+} PN_RS_RES_MAP;
+
+
+
+typedef struct pn_rs_triangle {
+
+	PN_HEADER		pn_h;
+
+/* cut
+	struct triangle *	next;
+*/
+/* NEXT record or PREV record
+	struct triangle *	c; 
+*/
+/* tag name string after this structure
+	MAP_POINT_LIST *	ptl[3];
+*/
+	GB_POINT		ptp[3];
+	AFFEN2D			a;
+	REAL1			resolution_rate;
+	GB_RECT			minrect;
+} PN_RS_TRIANGLE;
+
+typedef struct pn_rs_map_point_list {
+
+	PN_HEADER	pn_h;
+
+/* cut
+	RING_TYPE	h;
+*/
+/* string after this structure
+	L_CHAR *	tag;
+*/
+	GB_POINT	src;
+	GB_POINT	dest;
+} PN_RS_MAP_POINT_LIST;
+
 
 /*******************************/
 
