@@ -171,13 +171,4 @@ char * change_delim_str(char * buf);
 L_CHAR * change_delim_l_char(L_CHAR * buf);
 char * normalize_delim_str(char * buf);
 
-#ifndef U_FILE_LIB
-int u_open(char *,int,...);
-#endif
-int u_close(int);
-int u_write(int,void *,int);
-int u_read(int,void*,int);
-int u_lseek(int,int,int);
-
-
 #endif
