@@ -178,7 +178,7 @@ retry:
 		sleep_task((int)s,blacklist_lock);
 		goto retry;
 	case BLS_ERROR:
-ss_printf("BLS_ERROR\n");
+ss_printf("BLS_ERROR %i\n",get_tid());
 		ret = BLS_ERROR;
 		bl->polling_interval = bl->polling_initial;
 		t = get_xltime() + bl->polling_interval;
