@@ -157,6 +157,7 @@ RS_T * n;
 SYS_QUEUE * que;
 L_CHAR * key;
 XL_INTERPRETER * xli;
+XL_SEXP * s;
 
 	que = (SYS_QUEUE *)GET_TKEY(d);
 	key = touch_qkey(que);
@@ -174,7 +175,7 @@ XL_INTERPRETER * xli;
 			gc_pop(0,0);
 			break;
 		}
-		get_type(n->ret);
+		for ( s = n->ret ; get_type(s) == XLT_PAIR ; s = cdr(s) );
 		set_d_sexp(n->d,n->ret);
 
 		free_url(&n->u);
