@@ -27,6 +27,7 @@
 #include	"task.h"
 #include	"mlong_char.h"
 #include	"lock_level.h"
+#include	"save_global.h"
 
 
 void gc_gb_file();
@@ -63,6 +64,11 @@ void
 init_parse_system()
 {
 	parse_lock = new_lock(LL_PARSE);
+
+	SG_TITLE;
+	sg("SEM",	"parse_lock",	&parse_lock);
+	sg("int",	"parse_lock_task",	&parse_lock_task);
+	sg("int",	"parse_lock_cnt",	&parse_lock_cnt);
 }
 
 void
